@@ -45,6 +45,7 @@ qw/
     debug
     decode_always
     error
+    headers
     http_method
     last_action
     logger
@@ -64,7 +65,7 @@ qw/
 /
 );
 
-our $VERSION = '1.1.11'; $VERSION=~s/\-.*$//;
+our $VERSION = '1.1.12'; $VERSION=~s/\-.*$//;
 
 sub new {
   my $class = shift;
@@ -245,6 +246,14 @@ sub get_api_name {
   return join("", map { ucfirst } split /_/, shift);
 }
 
+sub header {
+  my ($self, %headers) = @_;
+
+  my %new_headers = (%headers, %{$self->get_headers || {}});
+
+  $self->set_headers(\%new_headers);
+}
+
 sub invoke_api {
   my ( $self, $action, $parameters, $content_type ) = @_;
 
@@ -263,7 +272,7 @@ sub invoke_api {
       $content      = encode_json($parameters);
     }
     elsif ( ref($parameters) && reftype($parameters) eq 'ARRAY' ) {
-      $content_type = 'application/x-www-form-url-encoded'
+      $content_type = 'application/x-www-form-urlencoded'
         if $self->get_http_method ne 'GET';
 
       my @query_string;
@@ -274,7 +283,7 @@ sub invoke_api {
       $content = join( '&', @query_string );
     } ## end elsif ( ref($parameters) ...)
     else {
-      $content_type = 'application/x-www-form-url-encoded'
+      $content_type = 'application/x-www-form-urlencoded'
         if $self->get_http_method ne 'GET';
       
       $content = $parameters;
@@ -328,7 +337,7 @@ sub print_error {
 
   my $error = $self->get_error;
 
-  my $err_str = 'API ERROR (' . $self->get_last_action . '): ';
+  my $err_str = 'API ERROR (' . ($self->get_last_action // '') . '): ';
   
   if ( $error && ref($error) =~ /Amazon::API::Error/ ) {
     my $response = $error->get_response;
@@ -391,7 +400,7 @@ sub _set_request_content {
   if ( $self->get_http_method ne 'GET' ) {
     $request->content_type($content_type);
 
-    if ( $content_type eq 'application/x-www-form-url-encoded' ) {
+    if ( $content_type eq 'application/x-www-form-urlencoded' ) {
       $content = $self->_set_form_url_encoded_string($content);
     }
 
@@ -430,6 +439,15 @@ sub submit {
     $self->get_credentials->get_token )
     if $self->get_credentials->get_token;
 
+  # add additional headers?
+  if ( $self->get_headers && reftype($self->get_header) eq 'HASH') {
+    my %headers = %{$self->get_headers};
+    
+    for my $k (keys %headers) {
+      $request->header($k, $headers{$k});
+    }
+  }
+  
   # sign the request
   $self->get_signer->sign( $request, $self->get_region );
 
